@@ -1,5 +1,5 @@
 package Tree::RB::XS;
-$Tree::RB::XS::VERSION = '0.01';
+$Tree::RB::XS::VERSION = '0.02';
 # VERSION
 # ABSTRACT: Similar API to Tree::RB implemented in C
 
@@ -10,7 +10,7 @@ require XSLoader;
 XSLoader::load('Tree::RB::XS', $Tree::RB::XS::VERSION);
 use Exporter 'import';
 our @_key_types= qw( KEY_TYPE_ANY KEY_TYPE_INT KEY_TYPE_FLOAT KEY_TYPE_BSTR KEY_TYPE_USTR );
-our @_cmp_enum= qw( CMP_PERL CMP_INT CMP_FLOAT CMP_MEMCMP CMP_UTF8 );
+our @_cmp_enum= qw( CMP_PERL CMP_INT CMP_FLOAT CMP_MEMCMP CMP_UTF8 CMP_NUMSPLIT );
 our @_lookup_modes= qw( GET_EQ GET_EQ_LAST GET_GT GET_LT GET_GE GET_LE GET_LE_LAST GET_NEXT GET_PREV
                         LUEQUAL LUGTEQ LULTEQ LUGREAT LULESS LUNEXT LUPREV );
 our @EXPORT_OK= (@_key_types, @_cmp_enum, @_lookup_modes);
@@ -18,6 +18,7 @@ our %EXPORT_TAGS= (
 	key_type => \@_key_types,
 	cmp      => \@_cmp_enum,
 	lookup   => \@_lookup_modes,
+	all      => \@EXPORT_OK,
 );
 
 
@@ -32,6 +33,7 @@ sub new {
 }
 
 
+*root= *root_node;
 *min= *min_node;
 *max= *max_node;
 *nth= *nth_node;
@@ -121,7 +123,7 @@ trusting it with production data.
   # optimize for floating-point comparisons
   $tree= Tree::RB::XS->new(key_type => 'float', allow_duplicates => 1);
   $tree->put(rand() => 1);
-  $tree->delete(0, $tree->get(.5, GET_LT));
+  $tree->delete(0, $tree->get_node_lt(.5));
 
   # optimize for byte strings
   $tree= Tree::RB::XS->new(key_type => KEY_TYPE_BSTR);
@@ -198,7 +200,7 @@ Whether to allow two nodes with the same key.  Defaults to false.
 
 =item L</compat_list_get>
 
-Whether to enable full compatibility with L<Tree::RB>'s list-context behaviors.
+Whether to enable full compatibility with L<Tree::RB>'s list-context behavior for L</get>.
 Defaults to false.
 
 =back
@@ -228,7 +230,7 @@ Specifies the function that compares keys.  Read-only; pass as an option to
 the constructor.
 
 This is one of: L</CMP_PERL>, L</CMP_INT>, L</CMP_FLOAT>, L</CMP_MEMCMP>,
-L</CMP_UTF8>, or a coderef.
+L</CMP_UTF8>, L</CMP_NUMSPLIT>, or a coderef.
 
 If set to a perl coderef, it should take two parameters and return an integer
 indicating their order in the same manner as Perl's C<cmp>.
@@ -251,16 +253,41 @@ already existed.  The initial value is false.
 
 =head2 compat_list_get
 
-Boolean, read/write.  Controls whether C</get> returns multiple values in list context.
-I wanted to match the API of L<Tree::RB>, but I can't bring myself to make an innocent-named
+Boolean, read/write.  Controls whether L</get> returns multiple values in list context.
+I wanted to match the API of C<Tree::RB>, but I can't bring myself to make an innocent-named
 method like 'get' change its behavior in list context.  So, by deault, this attribute is
-false and 'get' always returns a scalar.  But if you set this to true, C<get> changes in
-list context to also return the Node, like is done in C<Tree::RB>.
+false and C<get> always returns one value.  But if you set this to true, C<get> changes in
+list context to also return the Node, like is done in L<Tree::RB/lookup>.
 
 =head2 size
 
 Returns the number of elements in the tree.
 
+=head2 root_node
+
+Get the root node of the tree, or C<undef> if the tree is empty.
+
+Alias: C<root>
+
+=head2 min_node
+
+Get the tree node with minimum key.  Returns undef if the tree is empty.
+
+Alias: C<min>
+
+=head2 max_node
+
+Get the tree node with maximum key.  Returns undef if the tree is empty.
+
+Alias: C<max>
+
+=head2 nth_node
+
+Get the Nth node in the sequence from min to max.  N is a zero-based index.
+You may use negative numbers to count down form max.
+
+Alias: C<nth>
+
 =head1 METHODS
 
 =head2 get
@@ -269,10 +296,11 @@ Returns the number of elements in the tree.
                 ->get($key, $mode);
 
 Fetch a value from the tree, by its key.  Unlike L<Tree::RB/get>, this always
-returns a single value, regardless of list context.
+returns a single value, regardless of list context.  But, you can set
+L<compat_list_get> to make C<get> an alias for C<lookup>.
 
 Mode can be used to indicate something other than an exact match:
-L</GET_EQ>, L</GET_LE>, L</GET_LT>, L</GET_GE>, L</GET_GT>.
+L</GET_EQ>, L</GET_EQ_LAST>, L</GET_LE>, L</GET_LE_LAST>, L</GET_LT>, L</GET_GE>, L</GET_GT>.
 
 =head2 get_node
 
@@ -280,6 +308,24 @@ Same as L</get>, but returns the node instead of the value.  In trees with
 duplicate keys, this always returns the first node.  (nodes with identical keys
 are preserved in the order they were added)
 
+Aliases with built-in mode constants:
+
+=over 20
+
+=item get_node_last
+
+=item get_node_le
+
+=item get_node_le_last
+
+=item get_node_lt
+
+=item get_node_ge
+
+=item get_node_gt
+
+=back
+
 =head2 get_all
 
   my @values= $tree->get_all($key);
@@ -329,29 +375,6 @@ If you want to delete a range *exclusive* of one or both ends of the range, just
 use the C</get> method with the desired mode to look up each end of the nodes that
 you do want removed.
 
-=head2 min_node
-
-Get the tree node with minimum key.  Returns undef if the tree is empty.
-
-Alias: C<min>
-
-=head2 max_node
-
-Get the tree node with maximum key.  Returns undef if the tree is empty.
-
-Alias: C<max>
-
-=head2 nth_node
-
-Get the Nth node in the sequence from min to max.  N is a zero-based index.
-You may use negative numbers to count down form max.
-
-Alias: C<nth>
-
-=head2 root
-
-Get the root node of the tree, or C<undef> if the tree is empty.
-
 =head2 iter
 
   my $iter= $tree->iter;
@@ -513,6 +536,43 @@ Compare the keys as UTF8 byte strings, using Perl's internal C<bytes_cmp_utf8> f
 
 Compare the keys using C's C<memcmp> function.
 
+=item CMP_NUMSPLIT
+
+Compare using the equivalent of this coderef:
+
+  sub {
+    my @a_parts= split /([0-9]+)/, $_[0];
+    my @b_parts= split /([0-9]+)/, $_[1];
+    my $i= 0;
+    while ($i < @a_parts || $i < @b_parts) {
+      no warnings 'uninitialized';
+      my $cmp= ($i & 1)? ($a_parts[$i] <=> $b_parts[$i])
+             : ($a_parts[$i] cmp $b_parts[$i]);
+      return $cmp if $cmp;
+      ++$i;
+    }
+    return 0;
+  }
+
+except the XS implementation is not limited by the integer size of perl,
+and operates directly on the strings without splitting anything. (i.e. much faster)
+
+This results in a sort where integer portions of a string are sorted numerically,
+and any non-digit segment is compared as a string.  This produces sort-orders like
+the following:
+
+  2020-01-01
+  2020-4-7
+  2020-10-12
+
+or
+
+  14.4.2
+  14.14.0
+
+If the C<key_type> is C<KEY_TYPE_BSTR> this will sort the string portions using
+C<memcmp>, else they are sorted with Perl's unicode-aware sort.
+
 =back
 
 =head2 Lookup Mode
@@ -583,7 +643,7 @@ Michael Conrad <mike@nrdvana.net>
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 COPYRIGHT AND LICENSE
 
